import { useState } from "react";
import { Navbar, NavbarContent, NavbarMenuToggle, NavbarMenu, NavbarMenuItem, Link, NavbarBrand, NavbarItem } from "@nextui-org/react";
import Counter from "@/feature/messenger/components/ui/badges/Counter";
import { closeSession } from "@/feature/messenger/utils/CloseSession";
import { useSession } from "next-auth/react";
import { useRouter } from "next/navigation";
import { useTranslation } from "@/src/hooks/useTranslation";
import { useTheme } from "next-themes";
import ChatConfigContext, { LeftSidebarType } from "@/feature/messenger/context/ChatConfigContext";
import useListContactStore from "@/feature/messenger/store/useListContactStore";
import useConfigChatStore from "../../../store/chat_store/useConfigChatStore";

export default function NavbarMobile() {
    const route = useRouter();
    const [isMenuOpen, setIsMenuOpen] = useState(false);
    const { data: session, status } = useSession();
    const { trans } = useTranslation();
    const { theme, setTheme } = useTheme();
    const setLeftSidebar = ChatConfigContext(state => state.setLeftSidebar);
    const leftSidebar = ChatConfigContext(state => state.leftSidebar);
    const hadlerSelectContactOption = useListContactStore(state => state.hadlerSelectContactOption);
    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const selectIdChatbot = id_chatbot

    const Logout = () => {
        closeSession();
    }

    const backOtherChat = () => {
        route.push('/chat/select')
    }
    const toggleTheme = () => {
        setTheme(theme === "light" ? "dark" : "light");
    };

    const handleClickContacts = () => {
        setLeftSidebar(LeftSidebarType.CONTACTS);
        hadlerSelectContactOption();
    }

    const pauseSession = async () => {
        const data = {
            id_chatbot: selectIdChatbot
        }
        try {
            const response = await fetch(`${process.env.ASSET_PREFIX}/api/pause-session`, {
                method: 'POST',
                body: JSON.stringify(data)
            });
    
            if (response.ok) {
                route.push('/pause');
                route.refresh();
            }
        } catch (error) {
            console.error('Error al pausar la sesión:', error);
        }
    };

    return (
        <Navbar onMenuOpenChange={setIsMenuOpen} className="md:hidden bg-indigo-500 text-white">
            <NavbarContent>
                <NavbarMenuToggle
                    aria-label={isMenuOpen ? "Close menu" : "Open menu"}
                    className="md:hidden"
                />
                <NavbarBrand>
                    <p className="font-bold text-inherit text-2xl">Chat</p>
                </NavbarBrand>
            </NavbarContent>
            <NavbarContent justify="end">
                <NavbarItem>
                    <Counter />
                </NavbarItem>
            </NavbarContent>
            <NavbarMenu>
                <NavbarMenuItem>
                    <Link
                        color="foreground"
                        className="w-full"
                        href="#"
                        size="lg"
                    >
                        {(session?.user?.name || "").toUpperCase() || "Cargando..."}
                    </Link>
                    <Link
                        color="primary"
                        className="w-full"
                        href="#"
                        size="lg"
                        onClick={handleClickContacts}
                    >
                        {trans('section_contacts_button_title')}
                    </Link>
                    <Link
                        color="primary"
                        className="w-full"
                        href="#"
                        size="lg"
                        onClick={toggleTheme}
                    >
                        {theme == "light" ? trans("dark_mode_button_title") : trans("light_mode_button_title")}
                    </Link>
                    <Link
                        color="primary"
                        className="w-full"
                        href="#"
                        size="lg"
                        onClick={backOtherChat}
                    >
                        {trans('back_selected_chatbot_button_title')}
                    </Link>
                    <Link
                        color="primary"
                        className="w-full"
                        href="#"
                        size="lg"
                        onClick={pauseSession}
                    >
                        {trans('pause_session_button_title')}
                    </Link>
                    <Link
                        color="danger"
                        className="w-full"
                        href="#"
                        size="lg"
                        onClick={Logout}
                    >
                        Cerrar Sesión
                    </Link>
                </NavbarMenuItem>
            </NavbarMenu>
        </Navbar>
    );
}
